<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
        <template #operationBtn-checkBtn="{ data, row }">
          <PreviewBtnV2
            class="pro-table-operation-btn"
            :url="convertApi2FormUrlBySeparator(row.checkFileUrl ?? '')"
            preview-btn-text="查看凭证"
          />
        </template>
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  AppContainer,
  useTable,
  ProTableV2,
  defineOperationBtns,
  PreviewBtnV2,
} from '@bole-core/components';
import { convertApi2FormUrlBySeparator } from '@/utils';
import { OrderInputType } from '@bole-core/core';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { EnterpriseRechargeStatusEnum } from '@/constants';

defineOptions({
  name: 'WithdrawalRecordView',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'creationTime',
    name: '申请提现日期',
  },
  {
    id: '2',
    enCode: 'checkTime',
    name: '审核通过日期',
  },
  {
    id: '3',
    enCode: 'amount',
    name: '提现金额',
  },
  {
    id: '4',
    enCode: 'remainAmount',
    name: '资金余额',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'checkBtn',
      name: '查看凭证',
    },
  },
]);

const route = useRoute();
const router = useRouter();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetEnterpriseDrawWithListInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        checkStatus: EnterpriseRechargeStatusEnum.CheckPassed,
        enterpriseId: id,
      };
      let res = await parkBountyApplyServices.getEnterpriseDrawWithList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      creationTime: { type: 'date', format: 'YYYY-MM-DD' },
      checkTime: { type: 'date', format: 'YYYY-MM-DD' },
      amount: { type: 'money' },
      remainAmount: { type: 'money' },
    },
  }
);

onMounted(async () => {
  await getList();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
